@@ -23,8 +23,10 @@ NULL
 #'     \item intersectColumns: A wrapper for \code{complete.cases} to return a
 #'     \code{MultiAssayExperiment} with only those biological units that have
 #'     measurements across all experiments
-#'     \item replicated: A function that identifies multiple samples that
+#'     \item replicated: Identifies, via logical vectors, \code{colname}s that
 #'     originate from a single biological unit within each assay
+#'     \item replicates: Provides the replicate \code{colname}s found with
+#'     the \code{replicated} function by their name, empty list if none
 #'     \item anyReplicated: Displays which assays have replicate measurements
 #'     \item mergeReplicates: A function that combines replicated / repeated
 #'     measurements across all experiments and is guided by the replicated
@@ -32,9 +34,14 @@ NULL
 #'     \item longFormat: A \code{MultiAssayExperiment} method that
 #'     returns a small and skinny \link{DataFrame}. The \code{colDataCols}
 #'     arguments allows the user to append \code{colData} columns to the data.
-#'     \item wideFormat: A function to return a wide \link{DataFrame} where
-#'     each row represents an observation. Optional \code{colDataCols} can be
-#'     added when using a \code{MultiAssayExperiment}.
+#'     \item wideFormat: A function to reshape the data in a
+#'     `MultiAssayExperiment` to a "wide" format \link{DataFrame}. Each row in
+#'     the `DataFrame` represents an observation (corresponding to an entry in
+#'     the `colData`). If replicates are present, their data will be appended at
+#'     the end of the corresponding row and will generate additional `NA` data.
+#'     It is recommended to remove or consolidate technical replicates with
+#'     `mergeReplicates`. Optional \code{colDataCols} can be added when the
+#'     original object is a \code{MultiAssayExperiment}.
 #'     \item hasRowRanges: A function that identifies ExperimentList elements
 #'     that have a \link[=RangedSummarizedExperiment-class]{rowRanges} method
 #'     \item getWithColData: A convenience function for extracting an assay
@@ -51,6 +58,8 @@ NULL
 #'
 #' @return See the itemized list in the description section for details.
 #'
+#' @md
+#'
 #' @examples
 #'
 #' example(MultiAssayExperiment)
@@ -100,15 +109,6 @@ intersectColumns <- function(x) {
 #' @export
 setGeneric("replicated", function(x) standardGeneric("replicated"))
 
-.matrixToList <- function(mat) {
-    nout <- ncol(mat)
-    listout <- vector("list", nout)
-    for (i in seq_along(listout))
-        listout[[i]] <- unname(mat[, i])
-    names(listout) <- colnames(mat)
-    listout
-}
-
 #' @rdname MultiAssayExperiment-helpers
 #'
 #' @details The \code{replicated} function finds replicate measurements in each
@@ -133,17 +133,16 @@ setGeneric("replicated", function(x) standardGeneric("replicated"))
 setMethod("replicated", "MultiAssayExperiment", function(x) {
     listMap <- mapToList(sampleMap(x))
     lapply(listMap, function(assayDF) {
-        pnames <- unique(assayDF[["primary"]])
-        lvect <- unlist(lapply(pnames, function(g) {
-            tots <- assayDF[["primary"]] %in% g
-            if (sum(tots) <= 1L)
-                tots <- rep(FALSE, nrow(assayDF))
-            tots
-        }))
-        lmat <- matrix(
-            lvect, ncol = length(pnames), dimnames = list(NULL, pnames)
-        )
-        IRanges::LogicalList(.matrixToList(lmat))
+        pnames <- assayDF[["primary"]]
+        IRanges::LogicalList(lapply(
+            S4Vectors::splitAsList(pnames, pnames),
+            function(g) {
+                if (identical(length(g), 1L))
+                    rep(FALSE, length(pnames))
+                else
+                    pnames %in% g
+            }
+        ))
     })
 })
 
@@ -158,6 +157,36 @@ setMethod("anyReplicated", "MultiAssayExperiment", function(x) {
     vapply(reps, function(x) any(as.matrix(x)), logical(1L))
 })
 
+#' @rdname MultiAssayExperiment-helpers
+#' @export
+setGeneric("replicates", function(x, ...) standardGeneric("replicates"))
+
+#' @rdname MultiAssayExperiment-helpers
+#'
+#' @details The \code{replicates} function (noun) returns the \code{colname}s
+#'   from the \code{sampleMap} that were identified as replicates. It returns a
+#'   list of \linkS4class{CharacterList}s for each assay present in the
+#'   \code{MultiAssayExperiment} and an inner entry for each biological unit
+#'   that has replicate observations in that assay.
+#'
+#' @export
+setMethod("replicates", "MultiAssayExperiment", function(x, ...) {
+    listMap <- mapToList(sampleMap(x))
+    lapply(
+        X = listMap,
+        FUN = function(assayDF) {
+            Filter(
+                f = function(y) {
+                    length(y) > 1
+                },
+                x = S4Vectors::splitAsList(
+                    assayDF[["colname"]], assayDF[["primary"]]
+                )
+            )
+        }
+    )
+})
+
 # mergeReplicates function ------------------------------------------------
 
 #' @rdname MultiAssayExperiment-helpers
@@ -225,7 +254,7 @@ setMethod("mergeReplicates", "ExperimentList",
         if (!length(replicates))
             stop("'replicates' must be a 'list' of replicated column elements",
                  "\n per biological unit")
-        expnames <- stats::setNames(names(x), names(x))
+        expnames <- .setNames(names(x), names(x))
         redList <- lapply(expnames,
             function(i, element, simply, replicate, ...) {
                 mergeReplicates(x = element[[i]], simplify = simply,
@@ -685,7 +714,7 @@ renamePrimary <- function(x, value) {
     nprime <- value[match(samplemap[["primary"]], old)]
     samplemap[["primary"]] <- nprime
     rownames(coldata) <- value
-    BiocGenerics:::replaceSlots(
+    BiocBaseUtils::setSlots(
         object = x,
         sampleMap = samplemap,
         colData = coldata
@@ -721,7 +750,7 @@ renameColname <- function(x, i, value) {
     smp <- listToMap(splitmp)
     colnames(expAssay) <- value
     exps[[i]] <- expAssay
-    BiocGenerics:::replaceSlots(
+    BiocBaseUtils::setSlots(
         object = x,
         sampleMap = smp,
         ExperimentList = exps
@@ -769,7 +798,7 @@ setMethod("splitAssays", "MultiAssayExperiment",
         sublist <- unlist(sublist, recursive = FALSE)
         names(sublist) <- gsub("\\.", "_", names(sublist))
 
-        BiocGenerics:::replaceSlots(
+        BiocBaseUtils::setSlots(
             object = x,
             ExperimentList = ExperimentList(sublist)
         )
@@ -797,7 +826,7 @@ setMethod("splitAssays", "MultiAssayExperiment",
 makeHitList <- function(x, patternList) {
     Colnames <- colnames(x)
     res <- lapply(
-        stats::setNames(nm = names(patternList)),
+        .setNames(nm = names(patternList)),
         function(pattname, patt) {
             grepl(patt[[pattname]], unlist(Colnames))
         }, patt = patternList
