@@ -3,7 +3,7 @@ NULL
 
 .warnnomatch <- function(type, values) {
     warning("'", type, "': ",
-        paste(S4Vectors:::selectSome(values), collapse = ", "),
+        paste(BiocBaseUtils::selectSome(values), collapse = ", "),
             "\n  could not be matched")
 }
 
@@ -23,7 +23,7 @@ NULL
     if (nrow(autoMap) && any(missingPrimary)) {
         notFound <- autoMap[missingPrimary, ]
         warning("Data dropped from ExperimentList (element - column):",
-            Biobase::selectSome(
+            BiocBaseUtils::selectSome(
                 paste("\n", notFound[["assay"]], "-", notFound[["colname"]]),
             ), "\nUnable to map to rows of colData", call. = FALSE)
         autoMap <- autoMap[!missingPrimary, ]
@@ -40,7 +40,7 @@ NULL
         pnames <- colnames[na.omit(pmatch)]
         if (!length(pnames) || all(is.na(pnames)))
             stop("No 'colnames' in experiments could be matched:\n  ",
-                 paste(S4Vectors:::selectSome(colnames), collapse = ", "))
+                 paste(BiocBaseUtils::selectSome(colnames), collapse = ", "))
         else if (length(noPrim))
             .warnnomatch("primary", colnames[noPrim])
         DataFrame(primary = pnames, colname = pnames)
@@ -57,11 +57,39 @@ NULL
 
 #' @describeIn ExperimentList Get the dimension names for
 #' an \code{ExperimentList} using \code{\linkS4class{CharacterList}}
+#' @importFrom methods as
+#' @export
 setMethod("dimnames", "ExperimentList", function(x) {
-    list(IRanges::CharacterList(lapply(x, function(g) dimnames(g)[[1]])),
-    IRanges::CharacterList(lapply(x, function(g) dimnames(g)[[2]])))
+    list(
+        as(lapply(x, function(g) dimnames(g)[[1]]), "CompressedCharacterList"),
+        as(lapply(x, function(g) dimnames(g)[[2]]), "CompressedCharacterList")
+    )
 })
 
+#' @describeIn ExperimentList Get the column names for an \code{ExperimentList}
+#'   as a \code{\linkS4class{CharacterList}} slightly more efficiently
+#'
+#' @importFrom BiocGenerics colnames
+#' @inheritParams BiocGenerics::colnames
+#'
+#' @export
+setMethod("colnames", "ExperimentList",
+    function(x, do.NULL = TRUE, prefix = "col") {
+        as(lapply(x, colnames), "CompressedCharacterList")
+    }
+)
+
+#' @describeIn ExperimentList Get the row names for an \code{ExperimentList}
+#'   as a \code{\linkS4class{CharacterList}} slightly more efficiently
+#'
+#' @importFrom BiocGenerics rownames
+#' @export
+setMethod("rownames", "ExperimentList",
+    function(x, do.NULL = TRUE, prefix = "row") {
+        as(lapply(x, rownames), "CompressedCharacterList")
+    }
+)
+
 #' @describeIn MultiAssayExperiment Get the dimension names
 #' for a \code{MultiAssayExperiment} object
 setMethod("dimnames", "MultiAssayExperiment", function(x) {
@@ -100,7 +128,7 @@ setMethod("$", "MultiAssayExperiment", function(x, name) {
         by = c("row.names", intersect(names(coldx), names(coldy))),
         all = TRUE, sort = FALSE, stringsAsFactors = FALSE)
     rownames(cdatz) <- cdatz[["Row.names"]]
-    cdatz <- cdatz[, names(cdatz) != "Row.names"]
+    cdatz <- cdatz[, names(cdatz) != "Row.names", drop = FALSE]
     metaz <- c(metadata(x), metadata(y))
     new("MultiAssayExperiment",
         ExperimentList = expz,
@@ -177,7 +205,7 @@ setMethod("c", "MultiAssayExperiment",
             stop("'sampleMap' must be a 'DataFrame', 'data.frame', or 'list'")
         newListMap <- c(mapToList(xmap),
             IRanges::SplitDataFrameList(sampleMap))
-        x <- BiocGenerics:::replaceSlots(x,
+        x <- BiocBaseUtils::setSlots(x,
             ExperimentList = c(experiments(x), exps),
             sampleMap = listToMap(newListMap)
         )
