@@ -263,10 +263,14 @@ setMethod("subsetByColData", c("MultiAssayExperiment", "ANY"), function(x, y) {
             call. = FALSE)
     newcoldata <- coldata[y, , drop = FALSE]
     listMap <- mapToList(sampleMap(x), "assay")
-    listMap <- lapply(listMap, function(elementMap, keepers) {
-        .matchReorderSub(elementMap, keepers)
-        }, keepers = rownames(newcoldata))
-    newMap <- listToMap(listMap)
+    listMap <- lapply(
+        listMap,
+        function(elementMap, keepers) {
+            .matchReorderSub(elementMap, keepers)
+        },
+        keepers = rownames(newcoldata)
+    )
+    newMap <- listToMap(listMap, fill = FALSE)
     columns <- lapply(listMap, function(mapChunk) {
         mapChunk[, "colname", drop = TRUE]
     })
@@ -279,7 +283,7 @@ setMethod("subsetByColData", c("MultiAssayExperiment", "ANY"), function(x, y) {
     )
     newSubset <- ExperimentList(newSubset)
 
-    BiocGenerics:::replaceSlots(x,
+    BiocBaseUtils::setSlots(x,
         ExperimentList = newSubset,
         colData = newcoldata,
         sampleMap = newMap,
